@@ -1,5 +1,9 @@
+import json
 import logging
 
+from qolsys_controller.zwave_service_meter import QolsysZwaveServiceMeter
+from qolsys_controller.zwave_service_multilevelsensor import QolsysZwaveServiceMultilevelSensor
+
 from .enum_zwave import ZwaveDeviceClass
 from .observable import QolsysObservable
 
@@ -35,6 +39,14 @@ class QolsysZWaveDevice(QolsysObservable):
         self._is_device_hidden: str = zwave_dict.get("is_device_hidden", "")
         self._last_updated_date: str = zwave_dict.get("last_updated_date", "")
         self._command_class_list: str = zwave_dict.get("command_class_list", "")
+        self._meter_capabilities: str = ""
+        self._multisensor_capabilities: str = ""
+
+        # Set Meter and MutilevelSensor Services if available
+        self._meter_endpoints: list[QolsysZwaveServiceMeter] = []
+        self._multilevelsensor_endpoints: list[QolsysZwaveServiceMultilevelSensor] = []
+        self.meter_capabilities = zwave_dict.get("meter_capabilities", "")
+        self.multisensor_capabilities = zwave_dict.get("multisensor_capabilities", "")
 
     def update_raw(self, payload: bytes) -> None:
         LOGGER.debug("Raw Update (node%s) - payload: %s", self.node_id, payload.hex())
@@ -101,6 +113,10 @@ class QolsysZWaveDevice(QolsysObservable):
             self._last_updated_date = data.get("last_updated_date", "")
         if "command_class_list" in data:
             self._last_updated_date = data.get("command_class_list", "")
+        if "multisensor_capabilities" in data:
+            self.multisensor_capabilities = data.get("multisensor_capabilities", "")
+        if "meter_capabilities" in data:
+            self.meter_capabilities = data.get("meter_capabilities", "")
 
         self.end_batch_update()
 
@@ -138,6 +154,88 @@ class QolsysZWaveDevice(QolsysObservable):
             self._node_battery_level = value
             self.notify()
 
+    @property
+    def meter_capabilities(self) -> str:
+        return self._meter_capabilities
+
+    @meter_capabilities.setter
+    def meter_capabilities(self, value: str) -> None:
+        if self._meter_capabilities != value:
+            # LOGGER.debug("ZWave%s (%s) - meter_capabilities: %s", self.node_id, self.node_name, value)
+            self._meter_capabilities = value
+
+            # Update Meter Service
+            try:
+                meter_services = json.loads(value)
+                for endpoint, service in meter_services.items():
+                    # Check if we already have this meter service
+                    meter_endpoint = None
+                    for meter in self._meter_endpoints:
+                        if meter.endpoint == endpoint:
+                            meter_endpoint = meter
+                            LOGGER.debug(
+                                "ZWave%s (%s) - Updating existing meter endpoint: %s",
+                                self.node_id,
+                                self.node_name,
+                                meter.endpoint,
+                            )
+                            meter_endpoint.update_iq2medi(service)
+                            break
+
+                    # Create new meter service if not found
+                    if meter_endpoint is None:
+                        LOGGER.debug("ZWave%s (%s) - Adding new meter endpoint: %s", self.node_id, self.node_name, endpoint)
+                        meter_endpoint = QolsysZwaveServiceMeter(self, endpoint, service)
+                        self._meter_endpoints.append(meter_endpoint)
+
+            except json.JSONDecodeError:
+                LOGGER.error("ZWave%s (%s) - Error parsing meter_capabilities:%s", self.node_id, self.node_name, value)
+                return
+
+    @property
+    def multisensor_capabilities(self) -> str:
+        return self._multisensor_capabilities
+
+    @multisensor_capabilities.setter
+    def multisensor_capabilities(self, value: str) -> None:
+        if self._multisensor_capabilities != value:
+            # LOGGER.debug("ZWave%s (%s) - multisensor_capabilities: %s", self.node_id, self.node_name, value)
+            self._multisensor_capabilities = value
+
+            # Update Multilevel Sensor Service
+            try:
+                sensor_services = json.loads(value)
+                for endpoint, service in sensor_services.items():
+                    # Check if we already have this meter service
+                    sensor_endpoint = None
+                    for sensor in self._multilevelsensor_endpoints:
+                        if sensor.endpoint == endpoint:
+                            sensor_endpoint = sensor
+                            LOGGER.debug(
+                                "ZWave%s (%s) - Updating existing multilevelsensor endpoint: %s",
+                                self.node_id,
+                                self.node_name,
+                                sensor_endpoint.endpoint,
+                            )
+                            sensor_endpoint.update_iq2medi(service)
+                            break
+
+                    # Create new meter service if not found
+                    if sensor_endpoint is None:
+                        LOGGER.debug(
+                            "ZWave%s (%s) - Adding new multilevelsensor endpoint: %s", self.node_id, self.node_name, endpoint
+                        )
+                        LOGGER.debug("create sensor service")
+                        sensor_endpoint = QolsysZwaveServiceMultilevelSensor(self, endpoint, service)
+                        self.multilevelsensor_endpoints.append(sensor_endpoint)
+                        LOGGER.debug(sensor_endpoint.sensors)
+
+            except json.JSONDecodeError:
+                LOGGER.error(
+                    "ZWave%s (%s) - Error parsing multilevelsensor_capabilities:%s", self.node_id, self.node_name, value
+                )
+                return
+
     @property
     def node_battery_level_value(self) -> int | None:
         try:
@@ -201,6 +299,14 @@ class QolsysZWaveDevice(QolsysObservable):
             self._partition_id = value
             self.notify()
 
+    @property
+    def meter_endpoints(self) -> list[QolsysZwaveServiceMeter]:
+        return self._meter_endpoints
+
+    @property
+    def multilevelsensor_endpoints(self) -> list[QolsysZwaveServiceMultilevelSensor]:
+        return self._multilevelsensor_endpoints
+
     @property
     def generic_device_type(self) -> ZwaveDeviceClass:
         try:
@@ -211,6 +317,12 @@ class QolsysZWaveDevice(QolsysObservable):
     def is_battery_enabled(self) -> bool:
         return self.node_battery_level_value is not None
 
+    def is_service_meter_enabled(self) -> bool:
+        return self._meter_endpoints != []
+
+    def is_service_multilevelsensor_enabled(self) -> bool:
+        return self._multilevelsensor_endpoints != []
+
     def to_dict_base(self) -> dict[str, str]:
         return {
             "_id": self._id,
@@ -238,4 +350,6 @@ class QolsysZWaveDevice(QolsysObservable):
             "is_device_hidden": self._is_device_hidden,
             "last_updated_date": self._last_updated_date,
             "command_class_list": self._command_class_list,
+            "multisensor_capabilities": self.multisensor_capabilities,
+            "meter_capabilities": self.meter_capabilities,
         }
