@@ -8,3 +8,6 @@ LOGGER = logging.getLogger(__name__)
 class QolsysGeneric(QolsysZWaveDevice):
     def __init__(self, zwave_dict: dict[str, str]) -> None:
         super().__init__(zwave_dict)
+
+    def update_raw(self, payload: bytes) -> None:
+        LOGGER.debug("Raw Update (node%s) - payload: %s", self.node_id, payload.hex())
