@@ -69,6 +69,9 @@ class QolsysLock(QolsysZWaveDevice):
             self._lock_paired_status = value
             self.notify()
 
+    def update_raw(self, payload: bytes) -> None:
+        pass
+
     def update_lock(self, data: dict[str, str]) -> None:  # noqa: PLR0912
         # Check if we are updating same zoneid
         node_id_update = data.get("node_id", "")
@@ -118,6 +121,7 @@ class QolsysLock(QolsysZWaveDevice):
             "opr": self._lock_opr,
             "partition_id": self._lock_partition_id,
             "doorlock_name": self.lock_name,
+            "node_id": self.lock_node_id,
             "status": self.lock_status,
             "created_by": self._lock_created_by,
             "created_date": self._lock_created_date,
